==> mgb-0.6.5.zip: language/lang_french_formal_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

// ============================ //
// lang_main.php - Français 1.1 //
// ============================ //

// Français formel (Vous) //
// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com // 
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

// strings of index.php
	$lang['install_directory_exists'] = "Le dossier d'installation n'a pas encore été supprimé.<br>Pour votre propre sécurité, faites-le maintenant, s'il vous plaît!<br>Mais, n'oubliez pas d'exécuter le fichier <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> après une mise à jour!";
	$lang['new_entry'] = "Nouvelle contribution";
	$lang['new_entry_descr'] = "Ici vous pouvez écrire une nouvelle entrée pour le livre d'hôtes";
	$lang['contact'] = "Contact";
	$lang['contact_descr'] = "Ici vous pouvez contacter l’administrateur";
	$lang['adminpanel'] = "Administration";
	$lang['adminpanel_descr'] = "Login";
	$lang['entry'] = "Entrée";
	$lang['entries'] = "Entrées";
	$lang['no_entries'] = "Malheureusement, il y a<br>aucune entrée.";
	$lang['entries_on_pages'] = "Entrées sur {PAGES} pages";
	$lang['page_first'] = "First page";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Aller à la page suivante";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Last page";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Aller à la page précédente";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Aller directement à cette entrée";
	$lang['from'] = "de";
	$lang['at'] = "à";
	$lang['oclock'] = "heures";
	$lang['comment'] = "Commentaire";
	$lang['email_yes'] = "E-Mail à {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} ne veut pas recevoir de courriels par le livre d’hôtes.";
	$lang['hp_of'] = "Site Internet de {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar de {ENTRY_NAME}";

// strings of newentry.php
	$lang['name'] = "Votre nom:";
	$lang['city'] = "Ville:";
	$lang['email'] = "E-Mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Site Internet:";
	$lang['message'] = "Votre message:";
	$lang['necessary_fields'] = "[ Les champs obligatoires sont marqués d'un astérisque (*) ]";
	$lang['user_notification'] = "M’avertir par e-Mail, quand l'entrée est activée, ou quand un commentaire a été déposé.";
	$lang['user_show_email'] = "Autoriser les autres utilisateurs à m'écrire un e-Mail à partir du formulaire de contact. Pour éviter les spams, mon adresse E-Mail n’est pas affichée.";
	$lang['send'] = "Envoyer";
	$lang['preview'] = "Aperçu";
	$lang['errormessage1'] = "Entrez un message, s'il vous plaît!";
	$lang['errormessage2'] = "Entrez une adresse e-Mail valide, s'il vous plaît!";
	$lang['errormessage3'] = "Entrez un nom, s'il vous plaît!";
	$lang['errormessage4'] = "n’est pas une adresse <br>e-Mail valide!";
	$lang['errormessage5'] = "n’est pas un numéro <br>ICQ valide!";
	$lang['errormessage6'] = "La barrière IP interdit une autre entrée!";
	$lang['errormessage7'] = "Le code de sécurité n’a pas été saisi ou il est incorrect!";
	$lang['errormessage8'] = "Cet utilisateur ne veut pas recevoir d’e-Mails!";
	$lang['errormessage9'] = "Une erreur s'est produite lors de l'envoi de l'e-Mail!";
	$lang['security_code'] = "Code de sécurité";
	$lang['captcha_what_is_that'] = "Qu’est ce que c’est?";
	$lang['captcha_wikipedia'] = "http://fr.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "L’envoi d’une nouvelle contribution nécessite l’entrée d'un code de sécurité pour empêcher les enregistrements automatiques. Entrez tous les lettres en MAJUSCULES, s’il vous plaît. Si le code n’est pas lisible, laissez le champ vide et cliquez sur ''Envoyer''. Ensuite, un nouveau code sera généré. Vos entrées seront conservées. S’il n’y a pas de nouveau code, cliquez à droit et ensuite sur ''Actualiser'', s’il vous plaît.";
	$lang['back_to_mainpage'] = "Retour à la page principale";
	$lang['back'] = "Retour";
	$lang['entry_success_mod'] = "Votre entrée a été enregistrée avec succès.<br>Elle sera évaluée par l’administrateur, puis activée.";
	$lang['entry_success'] = "Votre entrée a été enregistrée avec succès. Vous pouvez la regarder immédiatement.";
	$lang['forwarding'] = "Vous allez être redirigé automatiquement dans 5 secondes. Sinon, cliquez sur ''Retour à la page principale'', s’il vous plaît.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Gras";
	$lang['bbcode_help_italic'] = "Italique";
	$lang['bbcode_help_url'] = "Liens";
	$lang['bbcode_textsize'] = "Taille";
	$lang['bbcode_extrasmall'] = "Minuscule";
	$lang['bbcode_small'] = "Petit";
	$lang['bbcode_default'] = "Standard";
	$lang['bbcode_big'] = "Grand";
	$lang['bbcode_extrabig'] = "Géant";
	$lang['bbcode_textcolor'] = "Couleur Police";
	$lang['smileys'] = "Smileys:";
	$lang['sendmail_admin_title'] = "Nouvelle entrée dans le livre d’hôtes de '{NAME}'";
	$lang['sendmail_user_title'] = "Votre entrée chez {DOMAIN}";

// strings of email.php
	$lang['email_name'] = "Votre nom:";
	$lang['email_email'] = "Votre e-Mail:";
	$lang['email_message'] = "Votre message:";
	$lang['email_sent_to'] = "Cet e-Mail est envoyé à:";
	$lang['email_send'] = "Envoyer";
	$lang['email_caption'] = "E-Mail de '{NAME}' par le livre d’hôtes de {DOMAIN}";
	$lang['email_sender'] = "Expéditeur:";
	$lang['email_receiver'] = "Destinataire:";
	$lang['email_from'] = "via:";
	$lang['email_sendcopytome'] = "Je voudrais recevoir une copie de cet e-Mail.";
	$lang['email_success'] = "Votre e-Mail a été envoyé avec succès à l’utilisateur.";
?>

==> mgb-0.6.9.zip: language/lang_french_formal_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

// ============================ //
// lang_main.php - Français 1.4 //
// ============================ //

// Français formel (Vous) //
// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com // 
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

// strings of index.php
	$lang['install_directory_exists'] = "Le dossier d'installation n'a pas encore été supprimé.<br>Pour votre propre sécurité, faites-le maintenant, s'il vous plaît!<br>Mais, n'oubliez pas d'exécuter le fichier <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> après une mise à jour!";
	$lang['new_entry'] = "Nouvelle contribution";
	$lang['new_entry_descr'] = "Ici vous pouvez écrire une nouvelle entrée pour le livre d'hôtes";
	$lang['contact'] = "Contact";
	$lang['contact_descr'] = "Ici vous pouvez contacter l’administrateur";
	$lang['adminpanel'] = "Administration";
	$lang['adminpanel_descr'] = "Login";
	$lang['entry'] = "Entrée";
	$lang['entries'] = "Entrées";
	$lang['no_entries'] = "Malheureusement, il y a<br>aucune entrée.";
	$lang['entries_on_pages'] = "Entrées sur {PAGES} pages";
	$lang['page_first'] = "Aller à la première page";
	$lang['page_first_symbol'] = "&laquo;";	
	$lang['page_forwards'] = "Aller à la page suivante";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Aller à la dernière page";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Aller à la page précédente";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Aller directement à cette entrée";
	$lang['from'] = "de";
	$lang['at'] = "à";
	$lang['oclock'] = "heures";
	$lang['comment'] = "Commentaire";
	$lang['email_yes'] = "E-Mail à {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} ne veut pas recevoir de courriels par le livre d’hôtes.";
	$lang['hp_of'] = "Site Internet de {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar de {ENTRY_NAME}";

// strings of newentry.php
	$lang['name'] = "Votre nom:";
	$lang['city'] = "Ville:";
	$lang['email'] = "E-Mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Site Internet:";
	$lang['message'] = "Votre message:";
	$lang['necessary_fields'] = "[ Les champs obligatoires sont marqués d'un astérisque (*) ]";
	$lang['user_notification'] = "M’avertir par e-Mail, quand l'entrée est activée, ou quand un commentaire a été déposé.";
	$lang['user_show_email'] = "Autoriser les autres utilisateurs à m'écrire un e-Mail à partir du formulaire de contact. Pour éviter les spams, mon adresse E-Mail n’est pas affichée.";
	$lang['user_accept_akismet_service'] = "This entry will be checked by the plugin 'Akismet' on spam. I am aware of the circumstance, that personal data of me will be sent to a server in the United States of America and i do accept this.";
	$lang['send'] = "Envoyer";
	$lang['preview'] = "Aperçu";
	$lang['errormessage1'] = "Entrez un message, s'il vous plaît!";
	$lang['errormessage2'] = "Entrez une adresse e-Mail valide, s'il vous plaît!";
	$lang['errormessage3'] = "Entrez un nom, s'il vous plaît!";
	$lang['errormessage4'] = "n’est pas une adresse <br>e-Mail valide!";
	$lang['errormessage5'] = "n’est pas un numéro <br>ICQ valide!";
	$lang['errormessage6'] = "La barrière IP interdit une autre entrée!";
	$lang['errormessage7'] = "Le code de sécurité n’a pas été saisi ou il est incorrect!";
	$lang['errormessage8'] = "Cet utilisateur ne veut pas recevoir d’e-Mails!";
	$lang['errormessage9'] = "Une erreur s'est produite lors de l'envoi de l'e-Mail!";
	$lang['errormessage10'] = "Protection anti-spam: Le formulaire a été envoyé trop rapidement. Attendez encore {TIME_LOCK_REST} secondes, s'il vous plaît.";
	$lang['errormessage11'] = "The Akismet data privacy agreement was not accepted. It MUST be accepted to save the entry.";
	$lang['security_code'] = "Code de sécurité";
	$lang['captcha_what_is_that'] = "Qu’est ce que c’est?";
	$lang['captcha_wikipedia'] = "http://fr.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "L’envoi d’une nouvelle contribution nécessite l’entrée d'un code de sécurité pour empêcher les enregistrements automatiques. Entrez tous les lettres en MAJUSCULES, s’il vous plaît. Si le code n’est pas lisible, laissez le champ vide et cliquez sur ''Envoyer''. Ensuite, un nouveau code sera généré. Vos entrées seront conservées. S’il n’y a pas de nouveau code, cliquez à droit et ensuite sur ''Actualiser'', s’il vous plaît.";
	$lang['back_to_mainpage'] = "Retour à la page principale";
	$lang['back'] = "Retour";
	$lang['entry_success_mod'] = "Votre entrée a été enregistrée avec succès.<br>Elle sera évaluée par l’administrateur, puis activée.";
	$lang['entry_success'] = "Votre entrée a été enregistrée avec succès. Vous pouvez la regarder immédiatement.";
	$lang['forwarding'] = "Vous allez être redirigé automatiquement dans 5 secondes. Sinon, cliquez sur ''Retour à la page principale'', s’il vous plaît.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Gras";
	$lang['bbcode_help_italic'] = "Italique";
	$lang['bbcode_help_url'] = "Liens";
	$lang['bbcode_textsize'] = "Taille";
	$lang['bbcode_extrasmall'] = "Minuscule";
	$lang['bbcode_small'] = "Petit";
	$lang['bbcode_default'] = "Standard";
	$lang['bbcode_big'] = "Grand";
	$lang['bbcode_extrabig'] = "Géant";
	$lang['bbcode_textcolor'] = "Couleur Police";
	$lang['smileys'] = "Smileys:";
	$lang['sendmail_admin_title'] = "Nouvelle entrée dans le livre d’hôtes de '{NAME}'";
	$lang['sendmail_user_title'] = "Votre entrée chez {DOMAIN}";

// strings of email.php
	$lang['email_name'] = "Votre nom:";
	$lang['email_email'] = "Votre e-Mail:";
	$lang['email_message'] = "Votre message:";
	$lang['email_sent_to'] = "Cet e-Mail est envoyé à:";
	$lang['email_send'] = "Envoyer";
	$lang['email_caption'] = "E-Mail de '{NAME}' par le livre d’hôtes de {DOMAIN}";
	$lang['email_sender'] = "Expéditeur:";
	$lang['email_receiver'] = "Destinataire:";
	$lang['email_from'] = "via:";
	$lang['email_sendcopytome'] = "Je voudrais recevoir une copie de cet e-Mail.";
	$lang['email_success'] = "Votre e-Mail a été envoyé avec succès à l’utilisateur.";
?>
